==> apache-daffodil-3.5.0-src.zip: apache-daffodil-3.5.0-src/daffodil-codegen-c/src/main/scala/org/apache/daffodil/codegen/c/generators/BinaryIntegerKnownLengthCodeGenerator.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.daffodil.codegen.c.generators

import org.apache.daffodil.core.dsom.ElementBase

trait BinaryIntegerKnownLengthCodeGenerator extends BinaryValueCodeGenerator {

  // Generate C code to parse and unparse an integer element
  def binaryIntegerKnownLengthGenerateCode(
    e: ElementBase,
    lengthInBits: Long,
    signed: Boolean,
    cgState: CodeGeneratorState,
  ): Unit = {
    val cLengthInBits = lengthInBits match {
      case n if n <= 8 => 8
      case n if n <= 16 => 16
      case n if n <= 32 => 32
      case n if n <= 64 => 64
      case _ => e.SDE("Binary integer lengths longer than 64 bits are not supported.")
    }
    val primType = if (signed) s"int$cLengthInBits" else s"uint$cLengthInBits"
    val addField = valueAddField(e, lengthInBits, primType, _, cgState)
    val validateFixed = valueValidateFixed(e, _, cgState)

    binaryValueGenerateCode(e, addField, validateFixed, cgState)
  }
}

==> apache-daffodil-3.8.0-src.zip: apache-daffodil-3.8.0-src/daffodil-codegen-c/src/main/scala/org/apache/daffodil/codegen/c/generators/BinaryIntegerKnownLengthCodeGenerator.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.daffodil.codegen.c.generators

import org.apache.daffodil.core.dsom.ElementBase

trait BinaryIntegerKnownLengthCodeGenerator extends BinaryValueCodeGenerator {

  // Generate C code to parse and unparse an integer element
  def binaryIntegerKnownLengthGenerateCode(
    e: ElementBase,
    lengthInBits: Long,
    signed: Boolean,
    cgState: CodeGeneratorState
  ): Unit = {
    val cLengthInBits = lengthInBits match {
      case n if n <= 8 => 8
      case n if n <= 16 => 16
      case n if n <= 32 => 32
      case n if n <= 64 => 64
      case _ => e.SDE("Binary integer lengths longer than 64 bits are not supported.")
    }
    val primType = if (signed) s"int$cLengthInBits" else s"uint$cLengthInBits"
    val addField = valueAddField(e, lengthInBits, primType, _, cgState)
    val validateFixed = valueValidateFixed(e, _, cgState)

    binaryValueGenerateCode(e, addField, validateFixed, cgState)
  }
}
